==> apimodule-1.0.5.tar.gz: lib/msimpersaa/response/pendidikan_response.dart <==
class PendidikanResponse {
  bool con;
  String msg;
  List<PendidikanResults> results;

  PendidikanResponse({this.con, this.msg, this.results});

  PendidikanResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <PendidikanResults>[];
      json['results'].forEach((v) {
        results.add(PendidikanResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class PendidikanResults {
  int id;
  String nomorSttb;
  String tanggalSttb;
  String pendidikanTerakhir;
  String namaJurusan;
  String namaLembagaPendidikan;
  String tempat;
  String documen;
  String pathFile;

  PendidikanResults(
      {this.id,
      this.nomorSttb,
      this.tanggalSttb,
      this.pendidikanTerakhir,
      this.namaJurusan,
      this.namaLembagaPendidikan,
      this.tempat,
      this.documen,
      this.pathFile});

  PendidikanResults.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    nomorSttb = json['nomor_sttb'];
    tanggalSttb = json['tanggal_sttb'];
    pendidikanTerakhir = json['pendidikan_terakhir'];
    namaJurusan = json['nama_jurusan'];
    namaLembagaPendidikan = json['nama_lembaga_pendidikan'];
    tempat = json['tempat'];
    documen = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['nomor_sttb'] = this.nomorSttb;
    data['tanggal_sttb'] = this.tanggalSttb;
    data['pendidikan_terakhir'] = this.pendidikanTerakhir;
    data['nama_jurusan'] = this.namaJurusan;
    data['nama_lembaga_pendidikan'] = this.namaLembagaPendidikan;
    data['tempat'] = this.tempat;
    data['dokumen'] = this.documen;
    data['path_file'] = this.pathFile;
    return data;
  }
}

==> apimodule-1.0.6.tar.gz: lib/msimpersaa/response/pendidikan_response.dart <==
class PendidikanResponse {
  bool con;
  String msg;
  List<PendidikanResults> results;

  PendidikanResponse({this.con, this.msg, this.results});

  PendidikanResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <PendidikanResults>[];
      json['results'].forEach((v) {
        results.add(PendidikanResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class PendidikanResults {
  int id;
  String nomorSttb;
  String tanggalSttb;
  String pendidikanTerakhir;
  String namaJurusan;
  String namaLembagaPendidikan;
  String tempat;
  String document;
  String pathFile;

  PendidikanResults(
      {this.id,
      this.nomorSttb,
      this.tanggalSttb,
      this.pendidikanTerakhir,
      this.namaJurusan,
      this.namaLembagaPendidikan,
      this.tempat,
      this.document,
      this.pathFile});

  PendidikanResults.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    nomorSttb = json['nomor_sttb'];
    tanggalSttb = json['tanggal_sttb'];
    pendidikanTerakhir = json['pendidikan_terakhir'];
    namaJurusan = json['nama_jurusan'];
    namaLembagaPendidikan = json['nama_lembaga_pendidikan'];
    tempat = json['tempat'];
    document = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['nomor_sttb'] = this.nomorSttb;
    data['tanggal_sttb'] = this.tanggalSttb;
    data['pendidikan_terakhir'] = this.pendidikanTerakhir;
    data['nama_jurusan'] = this.namaJurusan;
    data['nama_lembaga_pendidikan'] = this.namaLembagaPendidikan;
    data['tempat'] = this.tempat;
    data['dokumen'] = this.document;
    data['path_file'] = this.pathFile;
    return data;
  }
}
